@@ -1,18 +1,24 @@
-#include "cdk.h"
+/* $Id: label_ex.c,v 1.8 2004/08/28 00:53:46 tom Exp $ */
+
+#include <cdk.h>
 
 #ifdef HAVE_XCURSES
-char *XCursesProgramName="label_ex";
+char *XCursesProgramName = "label_ex";
 #endif
 
-int main (int argc, char **argv)
+int main(int argc, char **argv)
 {
    /* Declare variables. */
    CDKSCREEN	*cdkscreen;
    CDKLABEL	*demo;
-   WINDOW 	*cursesWin;
+   WINDOW	*cursesWin;
    char		*mesg[10];
 
-   /* Set up CDK. */ 
+   CDK_PARAMS params;
+
+   CDKparseParams(argc, argv, &params, CDK_MIN_PARAMS);
+
+   /* Set up CDK. */
    cursesWin = initscr();
    cdkscreen = initCDKScreen (cursesWin);
 
@@ -26,10 +32,15 @@ int main (int argc, char **argv)
    mesg[3] = "<C>This line should be set to whatever the screen default is.";
 
    /* Declare the labels. */
-   demo	= newCDKLabel (cdkscreen, CENTER, CENTER, mesg, 4, TRUE, TRUE);
+   demo = newCDKLabel (cdkscreen,
+		       CDKparamValue(&params, 'X', CENTER),
+		       CDKparamValue(&params, 'Y', CENTER),
+		       mesg, 4,
+		       CDKparamValue(&params, 'N', TRUE),
+		       CDKparamValue(&params, 'S', TRUE));
 
-   /* Is the label NULL? */
-   if (demo == (CDKLABEL *)NULL)
+   /* Is the label null? */
+   if (demo == 0)
    {
       /* Clean up the memory. */
       destroyCDKScreen (cdkscreen);
@@ -39,7 +50,7 @@ int main (int argc, char **argv)
 
       /* Spit out a message. */
       printf ("Oops. Can't seem to create the label. Is the window too small?\n");
-      exit (1);
+      exit (EXIT_FAILURE);
    }
 
    /* Draw the CDK screen. */
@@ -49,7 +60,6 @@ int main (int argc, char **argv)
    /* Clean up. */
    destroyCDKLabel (demo);
    destroyCDKScreen (cdkscreen);
-   delwin (cursesWin);
    endCDK();
-   exit (0);
+   exit (EXIT_SUCCESS);
 }
